@@ -3,6 +3,8 @@ from .api.splits_requests import SplitsRequests
 from .data.splits import (
     load_split,
     dump_split,
+    load_splits,
+    dump_splits,
     load_split_definition,
     dump_split_definition,
     load_split_definitions,
@@ -26,12 +28,14 @@ from .models.splits.treatment import Treatment
 
 logging.getLogger(__name__).addHandler(logging.NullHandler())
 
-__version__ = "0.3.0"
+__version__ = "0.4.0"
 
 __all__ = [
     'SplitsRequests',
     'load_split',
     'dump_split',
+    'load_splits',
+    'dump_splits',
     'load_split_definition',
     'dump_split_definition',
     'load_split_definitions',
