@@ -4,6 +4,9 @@ from splitiorequests.models.splits.matcher import Matcher
 
 
 class MatcherSchema(Schema):
+    class Meta:
+        ordered = True
+
     matcher_type = fields.Str(required=True, data_key='type')
     string = fields.Str()
     negate = fields.Bool()
@@ -24,4 +27,4 @@ class MatcherSchema(Schema):
         new_data = data.copy()
         for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
-        return new_data
+        return dict(new_data)
