@@ -5,6 +5,9 @@ from splitiorequests.schemas.splits import traffic_type_schema, rule_schema, tre
 
 
 class SplitDefinitionSchema(Schema):
+    class Meta:
+        ordered = True
+
     name = fields.Str()
     environment = fields.Nested(environment_schema.EnvironmentSchema)
     trafficType = fields.Nested(traffic_type_schema.TrafficTypeSchema)
@@ -26,6 +29,6 @@ class SplitDefinitionSchema(Schema):
     @post_dump
     def clean_empty(self, data, **kwargs):
         new_data = data.copy()
-        for field_key in (key for key in data if data[key] is None and key != 'tags'):
+        for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
-        return new_data
+        return dict(new_data)
