@@ -3,6 +3,9 @@ from splitiorequests.models.splits.treatment import Treatment
 
 
 class TreatmentSchema(Schema):
+    class Meta:
+        ordered = True
+
     name = fields.Str(required=True)
     description = fields.Str()
     configurations = fields.Str()
@@ -18,4 +21,4 @@ class TreatmentSchema(Schema):
         new_data = data.copy()
         for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
-        return new_data
+        return dict(new_data)
